<?php

remove_shortcode('gallery', 'gallery_shortcode');
add_shortcode('gallery', 'opulence_gallery_shortcode');

function opulence_gallery_shortcode($attr) {

	global $post;
	
	static $instance = 0;
	$instance++;
	
	// Define some default options
	$options = array(
		'order'      =>  'ASC', 
		'orderby'    =>  'menu_order ID',
		'id' 	     =>  $post->ID,
		'columns'    =>  '3',
		'title'    =>  'false',
		'perpage'    =>  '10', 
		'link'       =>  'attachment', 
		'include'    => '',
		'exclude'    => ''
	);
	
	// We're trusting author input, so let's at least make sure it looks like a valid orderby statement
	if ( isset( $attr['orderby'] ) ) {
		$attr['orderby'] = sanitize_sql_orderby( $attr['orderby'] );
		if ( !$attr['orderby'] )
			unset( $attr['orderby'] );
	}
	
	// Overwrite the defaults with any options passed in
	if (is_array($attr)) $options = array_merge($options, $attr);
	
	// Start by getting the attachments
	$attachments = get_children(array(
		'post_parent'=> $post->ID, 
		'post_status'=>'inherit', 
		'post_type'=> 'attachment', 
		'post_mime_type'=>'image', 
		'order'=> $options['order'], 
		'orderby'=> $options['orderby'], 
		'include'=> $options['include'],
		'exclude'=> $options['exclude']
	));
	
	$order = $options['order'];
	$orderby = $options['orderby'];
	$id = $options['id'];
	$columns = intval($options['columns']);
	$title = $options['title'];
	$include = intval($options['include']);
	$exclude = intval($options['exclude']);

	$id = intval($id);
	if ( 'RAND' == $order )
		$orderby = 'none';

	if ( !empty($include) ) {
		$include = preg_replace( '/[^0-9,]+/', '', $include );
				
		$_attachments = get_posts( array('include' => $include, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );

		$attachments = array();
		foreach ( $_attachments as $key => $val ) {
			$attachments[$val->ID] = $_attachments[$key];
				
		}
		
	} elseif ( !empty($exclude) ) {
		$exclude = preg_replace( '/[^0-9,]+/', '', $exclude );
			
		$attachments = get_children( array('post_parent' => $id, 'exclude' => $exclude, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	
	} else {
		$attachments = get_children( array('post_parent' => $id, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	}

	if ( empty($attachments) )
		return '';

	// Output feed if requested
	if ( is_feed() ) {
		$output = "\n";

		foreach ( $attachments as $id => $attachment )
			$output .= wp_get_attachment_link($id, $size, true) . "\n";
		return $output;
	}

	// Standard post output
	
	// Work out how many pages we need and what page we are currently on
	$imageCount = count($attachments);
	$pageCount = ceil($imageCount / $options['perpage']);
	
	if( isset ($_GET['gallery_id']) ) {
		$currentPage = intval($_GET['gallery_id']);
	}
	
	if ( empty($currentPage) || $currentPage<=0 ) $currentPage=1;
	
	$maxImage = $currentPage * $options['perpage'];
	$minImage = ($currentPage-1) * $options['perpage'];

	if ($pageCount > 1)
	{
		$page_link= get_permalink();
		$page_link_perma= true;
		if ( strpos($page_link, '?')!==false )
			$page_link_perma= false;

		$gplist= '<div id="gallery-pagination"><p>';
		for ( $j=1; $j<= $pageCount; $j++)
		{
			if ( $j==$currentPage )
				$gplist .= '<span class="page-link">'.$j.'</span>&nbsp;';
			else
				$gplist .= '<a href="'.$page_link. ( ($page_link_perma?'?':'&amp;') ). 'gallery_id='.$j.'"><span class="page-link">'.$j.'</span></a>&nbsp;';
		}

		$gplist .= '</p></div>';
	}
	else
		$gplist= '';

	if ( $columns == 1 ) {
		$size = "gallery-thumb-large";
	}
	
	elseif ( $columns == 2 ) {
		$size = "gallery-thumb-large";
	}
	
	elseif ( $columns == 3 ) {
		$size = "gallery-thumb-large";
	}
	
	elseif ( $columns == 4 ) {
		$size = "gallery-thumb-large";
	}

	$size_class = sanitize_html_class( $size );
	
	
	if ($columns == 3 ) {
		$column_class = 'photo-gallery-3';
	}
	elseif ($columns == 4) {
		$column_class = 'photo-gallery-4';
	}
	else {
		$column_class = 'photo-gallery-3';
	}
	
	$output = '<ul class="columns-' . $columns . ' photo-gallery ' . $column_class . '">';

	$i = 0;
	$k = 0;
	$count = 0;
	
	foreach ( $attachments as $id => $attachment ) {
		if ($k >= $minImage && $k < $maxImage) {	
			
	$image_thumb = wp_get_attachment_image_src( $id, $size, false ); // returns an array
	$image_full = wp_get_attachment_image_src( $id, 'full', false ); // returns an array		
	
	$output .= '<li class="col' . $columns . '">';	
	$output .= '<a href="' . $image_full[0] . '" rel="prettyPhoto[gallery-' . $options['id'] . ']" title="' . wptexturize($attachment->post_title) . '"><img src="' . $image_thumb[0] . '" alt="" />';

	//Turn gallery titles on/off
	if ( $title == 'true' ) {
		$output .= '<h4>' . wptexturize($attachment->post_title) . 
		'<span>' . wptexturize($attachment->post_excerpt) . '</span></h4>';
	}
	
	$output .= "</a></li>";
	
	if ( $columns > 0 && ++$i % $columns == 0 )
		$output .= '';
	}
		$k++;
}
	
	$output .= "</ul>";
	$output .= '<br style="clear: both" />' . $gplist;

	return $output;

}

?>