<?php

// Widget Class
class qns_lookbook_widget extends WP_Widget {


/* ------------------------------------------------
	Widget Setup
------------------------------------------------ */

	function qns_lookbook_widget() {
		$widget_ops = array( 'classname' => 'lookbook_widget', 'description' => __('Display Latest Look Book Items', 'qns') );
		$control_ops = array( 'width' => 300, 'height' => 300, 'id_base' => 'lookbook_widget' );
		$this->WP_Widget( 'lookbook_widget', __('Custom Look Book Widget', 'qns'), $widget_ops, $control_ops );
	}


/* ------------------------------------------------
	Display Widget
------------------------------------------------ */
	
	function widget( $args, $instance ) {
		extract( $args );
		
		$title = apply_filters('widget_title', $instance['title'] );
		$post_limit = $instance['post_limit'];

		echo $before_widget;

		if ( $title ) {
			echo $before_title . $title . $after_title;
		 } ?>

			<?php // Set News Limit
			if ( $instance['post_limit'] ) : 
				$lookbook_perpage = $instance['post_limit'];
			elseif ( !is_numeric ( $instance['post_limit'] ) )	:
				$lookbook_perpage = '4';
			else :
				$lookbook_perpage = '4';
			endif;
			?>
			
			<?php query_posts( "post_type=lookbook&posts_per_page=$lookbook_perpage" );

		    if( have_posts() ) : ?>
				
			<ul class="lookbook-widget clearfix">
		
			<?php while( have_posts() ) : the_post(); ?>

				<li>
					<div class="image-frame">
						<a href="<?php echo get_permalink(); ?>" rel="bookmark">

							<?php // Display Thumbnail
							if( has_post_thumbnail() ) :
								the_post_thumbnail( 'lookbook-widget' );
							else :
								echo '<img src="' . get_template_directory_uri() . '/images/noimage.png" alt="" />';
							endif; 
							?>

						</a>
					</div>

				</li>
						
			<?php endwhile; ?>
				
			</ul>
			
			<?php
			
			// Fetch options stored in $data
			global $data;
			
			if($data['lookbook_id']) {
				$lookbook_page = home_url() . '/?page_id=' . $data['lookbook_id'];
			} else {
				$lookbook_page = '#';
			}
			
			?>
			
			<p><a href="<?php echo $lookbook_page; ?>" class="button1"><?php _e('Open Look Book','qns'); ?> &raquo;</a></p>
			<div class="clearboth"></div>
				
			<?php else : ?>

				<p><?php _e('No items have been added to the Lookbook yet','qns'); ?></p>
				
			<?php endif; ?>
			
		<?php
		
		echo $after_widget;
	}	
	
	
/* ------------------------------------------------
	Update Widget
------------------------------------------------ */
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['post_limit'] = strip_tags( $new_instance['post_limit'] );
		return $instance;
	}
	
	
/* ------------------------------------------------
	Widget Input Form
------------------------------------------------ */
	 
	function form( $instance ) {
		$defaults = array(
		'title' => 'Lookbook',
		'post_limit' => '4'
		);
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>
				
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'qns'); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'post_limit' ); ?>"><?php _e('Post Limit:', 'qns') ?></label>
			<input type="text" size="3" id="<?php echo $this->get_field_id('post_limit'); ?>" name="<?php echo $this->get_field_name('post_limit'); ?>" value="<?php echo $instance['post_limit']; ?>" />
		</p>
		
	<?php
	}	
	
}

// Add widget function to widgets_init
add_action( 'widgets_init', 'qns_lookbook_widget' );

// Register Widget
function qns_lookbook_widget() {
	register_widget( 'qns_lookbook_widget' );
}