<?php
/**
 * Cart Page
 */
 
global $woocommerce;
?>

<?php $woocommerce->show_messages(); ?>

<form action="<?php echo esc_url( $woocommerce->cart->get_cart_url() ); ?>" method="post">
<?php do_action( 'woocommerce_before_cart_table' ); ?>
<table class="product-table" width="100%">
	<thead>
		<tr>
			<th class="product-remove"><?php _e('Remove', 'woocommerce'); ?></th>
			<th class="product-name"><?php _e('Product Name', 'woocommerce'); ?></th>
			<th class="product-price"><?php _e('Price', 'woocommerce'); ?></th>
			<th class="product-quantity"><?php _e('Quantity', 'woocommerce'); ?></th>
			<th class="product-subtotal"><?php _e('Total', 'woocommerce'); ?></th>
		</tr>
	</thead>
	<tbody>
		<?php do_action( 'woocommerce_before_cart_contents' ); ?>
		
		<?php
		if ( sizeof( $woocommerce->cart->get_cart() ) > 0 ) {
			foreach ( $woocommerce->cart->get_cart() as $cart_item_key => $values ) {
				$_product = $values['data'];
				if ( $_product->exists() && $values['quantity'] > 0 ) {
					?>
					<tr class = "<?php echo esc_attr( apply_filters('woocommerce_cart_table_item_class', 'cart_table_item', $values, $cart_item_key ) ); ?>">
						<!-- Remove from cart link -->
						<td data-title="Remove" class="product-remove">
							<?php 
								echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf('<a href="%s" class="remove" title="%s">&times;</a>', esc_url( $woocommerce->cart->get_remove_url( $cart_item_key ) ), __('Remove this item', 'woocommerce') ), $cart_item_key ); 
							?>
						</td>
						
						<!-- Product Name -->
						<td data-title="Product Name" class="product-name">
							<?php 
								if ( ! $_product->is_visible() || ( $_product instanceof WC_Product_Variation && ! $_product->parent_is_visible() ) )
									echo apply_filters( 'woocommerce_in_cart_product_title', $_product->get_title(), $values, $cart_item_key );
								else
									printf('<a href="%s">%s</a>', esc_url( get_permalink( apply_filters('woocommerce_in_cart_product_id', $values['product_id'] ) ) ), apply_filters('woocommerce_in_cart_product_title', $_product->get_title(), $values, $cart_item_key ) );
														
								// Meta data
								echo $woocommerce->cart->get_item_data( $values );
                   				
                   				// Backorder notification
                   				if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $values['quantity'] ) )
                   					echo '<p class="backorder_notification">' . __('Available on backorder', 'woocommerce') . '</p>';
							?>
						</td>
						
						<!-- Product price -->
						<td data-title="Price">
							<?php 							
								$product_price = get_option('woocommerce_display_cart_prices_excluding_tax') == 'yes' || $woocommerce->customer->is_vat_exempt() ? $_product->get_price_excluding_tax() : $_product->get_price();
							
								echo apply_filters('woocommerce_cart_item_price_html', woocommerce_price( $product_price ), $values, $cart_item_key ); 
							?>
						</td>
						
						<!-- Quantity inputs -->
						<td data-title="Quantity" class="qty-table product-quantity">
							
							<div class="qty-small">
							<?php
								if ( $_product->is_sold_individually() ) {
									$product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
								} else {

									$step	= apply_filters( 'woocommerce_quantity_input_step', '1', $_product );
									$min 	= apply_filters( 'woocommerce_quantity_input_min', '', $_product );
									$max 	= apply_filters( 'woocommerce_quantity_input_max', $_product->backorders_allowed() ? '' : $_product->get_stock_quantity(), $_product );

									$product_quantity = sprintf( '<div class="quantity"><input type="number" name="cart[%s][qty]" step="%s" min="%s" max="%s" value="%s" size="4" title="' . _x( 'Qty', 'Product quantity input tooltip', 'woocommerce' ) . '" class="input-text qty text" maxlength="12" /></div>', $cart_item_key, $step, $min, $max, esc_attr( $values['quantity'] ) );
								}

								echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key );
							?>
							</div>
							
						</td>
						
						<!-- Product subtotal -->
						<td data-title="Total" class="product-subtotal">
							<?php 
								echo apply_filters( 'woocommerce_cart_item_subtotal', $woocommerce->cart->get_product_subtotal( $_product, $values['quantity'] ), $values, $cart_item_key ); 
							?>
						</td>
					</tr>
					<?php
				}
			}
		}
		
		do_action( 'woocommerce_cart_contents' );
		?>
		
		<?php do_action( 'woocommerce_after_cart_contents' ); ?>
	</tbody>
</table>

<!-- BEGIN .clearfix -->
<div class="cart-options clearfix">

	<?php if ( get_option( 'woocommerce_enable_coupons' ) == 'yes' && get_option( 'woocommerce_enable_coupon_form_on_cart' ) == 'yes') { ?>
		<div class="coupon-form clearfix fl">
			
			<input type="text" name="coupon_code" class="coupon-code text_input" value="" /> 
			<input type="submit" class="button2 fr" name="apply_coupon" value="<?php _e('Apply Coupon', 'woocommerce'); ?>" style="margin: 2px 0 0 10px;" />
				
			<?php do_action('woocommerce_cart_coupon'); ?>
				
		</div>
	<?php } ?>
		
		<div class="cart-buttons fr">
			<input type="submit" class="button2" name="update_cart" value="<?php _e('Update Cart', 'woocommerce'); ?>" style="margin: 2px 10px 0 0;" /> 
			<a href="<?php echo esc_url( $woocommerce->cart->get_checkout_url() ); ?>" class="button2 buttonpad" style="margin: 2px 0 0 0;"><?php _e('Proceed to Checkout &rarr;', 'woocommerce'); ?></a>
			<?php do_action('woocommerce_proceed_to_checkout'); ?>
		
			<?php $woocommerce->nonce_field('cart') ?>
		
		</div>
		
<!-- END .clearfix -->
</div>

<?php do_action( 'woocommerce_after_cart_table' ); ?>
</form>

<hr class="margin1">

<div class="cart-collaterals">
	
	<?php do_action('woocommerce_cart_collaterals'); ?>
	
	<?php woocommerce_cart_totals(); ?>
	
	<?php woocommerce_shipping_calculator(); ?>
	
</div>